@@ -2,27 +2,32 @@
 try:
     from seleniumwire import webdriver
     # to add capabilities for chrome and firefox, import their Options with different aliases
-    from selenium.webdriver.chrome.options import Options as ChromeOptions
-    from selenium.webdriver.firefox.options import Options as FirefoxOptions
+    from selenium.webdriver.chrome.options import Options as CustomChromeOptions
+    from selenium.webdriver.firefox.options import Options as CustomFireFoxOptions
     # import webdriver for downloading respective driver for the browser
     from webdriver_manager.chrome import ChromeDriverManager
     from webdriver_manager.firefox import GeckoDriverManager
     from fake_headers import Headers
+    from selenium.webdriver.chrome.service import Service as ChromeService
+    from selenium.webdriver.firefox.service import Service as FirefoxService
+
 except Exception as ex:
     print(ex)
 
 
 class Initializer:
 
-    def __init__(self, browser_name, proxy=None):
+    def __init__(self, browser_name, headless, proxy=None):
         self.browser_name = browser_name
         self.proxy = proxy
+        self.headless = headless
 
     def set_properties(self, browser_option):
         """adds capabilities to the driver"""
         header = Headers().generate()['User-Agent']
-        browser_option.add_argument(
-            '--headless')  # runs browser in headless mode
+        if self.headless:
+            browser_option.add_argument(
+                '--headless')  # runs browser in headless mode
         browser_option.add_argument('--no-sandbox')
         browser_option.add_argument("--disable-dev-shm-usage")
         browser_option.add_argument('--ignore-certificate-errors')
@@ -37,7 +42,7 @@ class Initializer:
         """expects browser name and returns a driver instance"""
         # if browser is suppose to be chrome
         if browser_name.lower() == "chrome":
-            browser_option = ChromeOptions()
+            browser_option = CustomChromeOptions()
             # automatically installs chromedriver and initialize it and returns the instance
             if self.proxy is not None:
                 options = {
@@ -46,12 +51,13 @@ class Initializer:
                     'no_proxy': 'localhost, 127.0.0.1'
                 }
                 print("Using: {}".format(self.proxy))
-                return webdriver.Chrome(executable_path=ChromeDriverManager().install(),
+
+                return webdriver.Chrome(service=ChromeService(ChromeDriverManager().install()),
                                         options=self.set_properties(browser_option), seleniumwire_options=options)
 
-            return webdriver.Chrome(executable_path=ChromeDriverManager().install(), options=self.set_properties(browser_option))
+            return webdriver.Chrome(service=ChromeService(ChromeDriverManager().install()), options=self.set_properties(browser_option))
         elif browser_name.lower() == "firefox":
-            browser_option = FirefoxOptions()
+            browser_option = CustomFireFoxOptions()
             if self.proxy is not None:
                 options = {
                     'https': 'https://{}'.format(self.proxy.replace(" ", "")),
@@ -59,11 +65,12 @@ class Initializer:
                     'no_proxy': 'localhost, 127.0.0.1'
                 }
                 print("Using: {}".format(self.proxy))
-                return webdriver.Firefox(executable_path=GeckoDriverManager().install(),
+
+                return webdriver.Firefox(service=FirefoxService(executable_path=GeckoDriverManager().install()),
                                          options=self.set_properties(browser_option), seleniumwire_options=options)
 
             # automatically installs geckodriver and initialize it and returns the instance
-            return webdriver.Firefox(executable_path=GeckoDriverManager().install(), options=self.set_properties(browser_option))
+            return webdriver.Firefox(service=FirefoxService(executable_path=GeckoDriverManager().install()), options=self.set_properties(browser_option))
         else:
             # if browser_name is not chrome neither firefox than raise an exception
             raise Exception("Browser not supported!")
